@@ -192,7 +192,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 		Self::HEADER_SIZE as u64
 	} // }}}
 
-	#[instrument(err, level = "trace", skip(self))]
+	#[instrument(err, level = "trace", skip(self), fields(indexkv.path = %self.path.display()))]
 	async fn get_header(&mut self) -> Result<Header, Error> /* {{{ */ {
 		let mut buf = [0u8; size_of::<Header>()];
 		self.file.seek(SeekFrom::Start(0)).await?;
@@ -206,7 +206,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 		Ok(deserialize(&buf)?)
 	} // }}}
 
-	#[instrument(err, level = "trace", skip(self))]
+	#[instrument(err, level = "trace", skip(self), fields(indexkv.path = %self.path.display()))]
 	async fn get_index_entry(&mut self, i: u64) -> Result<IndexEntry, Error> /* {{{ */ {
 		let pos = self.index_start_position() + (i * Self::INDEX_ENTRY_SIZE as u64);
 		self.file.seek(SeekFrom::Start(pos)).await?;
@@ -214,7 +214,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 		Ok(entry)
 	} // }}}
 
-	#[instrument(err, level = "debug", skip(self))]
+	#[instrument(err, level = "debug", skip(self), fields(indexkv.path = %self.path.display()))]
 	async fn find_index_entry(&mut self, key: u64) -> Result<Option<IndexEntry>, Error> /* {{{ */ {
 		let mut size = self.header.pair_count;
 		let mut left = 0;
@@ -253,7 +253,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 		Ok(Some(deserialize(&buf)?))
 	} // }}}
 
-	#[instrument(err, level = "trace", skip(self))]
+	#[instrument(err, level = "trace", skip(self), fields(indexkv.path = %self.path.display()))]
 	async fn read_value_at(&mut self, position: u64) -> Result::<T, Error> /* {{{ */ {
 		self.file.seek(SeekFrom::Start(position)).await?;
 		match self.read_value().await? {
@@ -264,7 +264,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 
 	/// Reads the header and checks to see whether or not the store is valid; at this time, this
 	/// means making sure the format is fully up-to-date and writing completed.
-	#[instrument(err, level = "trace", skip(self))]
+	#[instrument(err, level = "trace", skip(self), fields(indexkv.path = %self.path.display()))]
 	#[inline]
 	pub async fn is_valid(&mut self) -> Result<bool, Error> /* {{{ */ {
 		let header = self.get_header().await?;
@@ -278,7 +278,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 	/// relational database parlance, this would be a tablescan.
 	// TODO:  Right now, nothing stops you from starting a stream then writing
 	//    to the Store.  This will, naturally, ruin everything.
-	#[instrument(err, level = "debug", skip(self))]
+	#[instrument(err, level = "debug", skip(self), fields(indexkv.path = %self.path.display()))]
 	#[inline]
 	pub async fn stream_values(&self) -> Result<impl Stream<Item=Result<T, Error>>, Error> /* {{{ */ {
 		let mut file = tokio::fs::OpenOptions::new()
@@ -296,7 +296,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 	/// Looks up a single value by key.  Will attempt to cache data positions in the backing file
 	/// to minimize disk seeking.  Returns [Error::NotFound] when `key` does not exist in the
 	/// Store.
-	#[instrument(err, level = "debug", skip(self))]
+	#[instrument(err, level = "debug", skip(self), fields(indexkv.path = %self.path.display()))]
 	#[inline]
 	pub async fn get(&mut self, key: u64) -> Result<T, Error> /* {{{ */ {
 		let position = match self.index_cache.get(&key) {
@@ -317,7 +317,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 	/// Looks up multiple values by key.  Will find (uncached) keys in sorted order to minimize
 	/// disk seeking back and forth.  Does _not_ return an error when `key` does not exist; calling
 	/// code should check for `Some` vs `None` in the resulting `HashMap` for fallibility.
-	#[instrument(err, level = "debug", skip(self))]
+	#[instrument(err, level = "debug", skip(self), fields(indexkv.path = %self.path.display()))]
 	pub async fn get_many(&mut self, keys_in: &[u64]) -> Result<HashMap<u64, T>, Error> /* {{{ */ {
 		let mut results = HashMap::with_capacity(keys_in.len());
 		let mut keys = Vec::new();
@@ -355,6 +355,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 	//   * Save current file position (as index_start_pos) and number of entries to the header
 	//   * Write the sorted index down to the file
 	//   * Seek to the beginning of the file and write down the header, with completed_writing = true
+	#[instrument(err, level = "info", skip(self, input_stream, writer), fields(indexkv.path = %self.path.display()))]
 	async fn write_to<S, W>(&mut self, mut input_stream: S, writer: &mut W) -> Result<(), StreamError<S::Error>> /* {{{ */
 	where
 		S: TryStream<Ok=(u64, T)> + Unpin,
@@ -467,6 +468,7 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 	///		));
 	///	}
 	/// ```
+	#[instrument(err, level = "debug", skip(self, input_stream), fields(indexkv.path = %self.path.display()))]
 	#[inline]
 	pub async fn write<S>(&mut self, input_stream: S) -> Result<(), StreamError<S::Error>> /* {{{ */
 	where
@@ -480,15 +482,16 @@ impl<T: Serialize + DeserializeOwned + std::fmt::Debug> Store<T> {
 
 	/// For cases where the incoming data stream is infallible, this allows you to avoid that
 	/// portion of error handling.
+	#[instrument(err, level = "debug", skip(self, input_stream), fields(indexkv.path = %self.path.display()))]
 	#[inline]
 	pub async fn write_infallible<S>(&mut self, input_stream: S) -> Result<(), Error> /* {{{ */
 	where
 		S: Stream<Item=(u64, T)> + Unpin
 	{
-		Ok(self.write(input_stream.map(Result::<_, Error>::Ok)).await.map_err(|e| match e {
+		self.write(input_stream.map(Result::<_, Error>::Ok)).await.map_err(|e| match e {
 			StreamError::Internal(e) => e,
 			_ => unreachable!()
-		})?)
+		})
 	} // }}}
 }
 
